# remirepo/fedora spec file for php-bjeavons-zxcvbn-php
#
# Copyright (c) 2019-2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%bcond_without       tests
# Github
%global gh_commit    994928ae5b17ecff8baa2406832d37bdf01116c0
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     bjeavons
%global gh_project   zxcvbn-php
# Packagist
%global pk_vendor    %{gh_owner}
%global pk_name      %{gh_project}
# PSR-0 namespace
%global ns_vendor    %nil
%global ns_project   ZxcvbnPhp

Name:           php-%{pk_vendor}-%{pk_name}
Version:        1.3.1
Release:        1%{?dist}
Summary:        Realistic password strength estimation PHP library

License:        MIT
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{name}-%{version}-%{gh_short}.tgz
# Create git snapshot as tests are excluded from official tarball
Source1:        makesrc.sh

BuildArch:      noarch
BuildRequires:  php(language) >= 7.3
%if %{with tests}
BuildRequires:  php-reflection
BuildRequires:  php-ctype
BuildRequires:  php-date
BuildRequires:  php-json
BuildRequires:  php-intl
BuildRequires:  php-mbstring
BuildRequires:  php-pcre
BuildRequires:  php-reflection
BuildRequires:  php-spl
# Recommended for 32-bit
BuildRequires:  php-gmp
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(symfony/polyfill-mbstring) >= 1.3.1  with php-composer(symfony/polyfill-mbstring) < 2)
# remirepo:4
%else
BuildRequires:  php-composer(symfony/polyfill-mbstring) <  2
BuildRequires:  php-composer(symfony/polyfill-mbstring) >= 1.3.1
%endif
# From composer.json, "require-dev": {
#        "phpunit/phpunit": "^8.5",
#        "php-coveralls/php-coveralls": "*",
#        "squizlabs/php_codesniffer": "3.*"
BuildRequires:  phpunit9
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": "^7.2 | ^8.0 | ^8.1",
#        "symfony/polyfill-mbstring": ">=1.3.1",
#        "ext-json": "*"
# "suggest": {
#        "ext-gmp": "Required for optimized binomial calculations (also requires PHP >= 7.3)"
Requires:       php(language) >= 7.3
Requires:       php-json
Requires:       php-gmp
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-composer(symfony/polyfill-mbstring) >= 1.3.1  with php-composer(symfony/polyfill-mbstring) < 2)
# remirepo:4
%else
Requires:       php-composer(symfony/polyfill-mbstring) <  2
Requires:       php-composer(symfony/polyfill-mbstring) >= 1.3.1
%endif
# From phpcompatifo report for 1.2.0
Requires:       php-ctype
Requires:       php-date
Requires:       php-intl
Requires:       php-mbstring
Requires:       php-pcre
Requires:       php-spl
# Autoloader
Requires:       php-composer(fedora/autoloader)

# Package replacement
Obsoletes:      php-mkopinsky-zxcvbn-php <= 4.4.2
Provides:       php-mkopinsky-zxcvbn-php  = 1:%{version}
Provides:       php-composer(mkopinsky/%{pk_name}) = 4.4.2
Provides:       php-composer(%{pk_vendor}/%{pk_name}) = %{version}


%description
Zxcvbn-PHP is a password strength estimator using pattern matching and minimum
entropy calculation. Zxcvbn-PHP is based on the the Javascript zxcvbn project
from Dropbox and @lowe. "zxcvbn" is bad password, just like "qwerty" and
"123456".

Autoloader: %{_datadir}/php/%{ns_project}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
: Generate a simple autoloader
%{_bindir}/phpab -t fedora -o src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{_datadir}/php/Symfony/Polyfill/autoload.php',
]);
EOF


%install
mkdir -p   %{buildroot}%{_datadir}/php
cp -pr src %{buildroot}%{_datadir}/php/%{ns_project}


%check
%if %{with tests}
: Generate a simple autoloader
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
// Installed library
require '%{buildroot}%{_datadir}/php/%{ns_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('ZxcvbnPhp\\Test\\', dirname(__DIR__).'/test');
EOF

: Run upstream test suite
ret=0
for cmd in php php74 php80 php81; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit9 $FILTER \
      --no-coverage --verbose || ret=1
  fi
done
exit $ret
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE.txt
%doc *.md
%doc composer.json
%{_datadir}/php/%{ns_project}


%changelog
* Wed Dec 22 2021 Remi Collet <remi@remirepo.net> - 1.3.1-1
- update to 1.3.1

* Tue Dec 14 2021 Remi Collet <remi@remirepo.net> - 1.3.0-2
- raise dependency on PHP 7.3
- add dependency on gmp extension for 32-bit

* Mon Dec 13 2021 Remi Collet <remi@remirepo.net> - 1.3.0-1
- update to 1.3.0
- add weak dependency on gmp extension
- switch to phpunit9

* Wed Apr 21 2021 Remi Collet <remi@remirepo.net> - 1.2.0-1
- initial package, version 1.2.0
- rename from php-mkopinsky-zxcvbn-php to php-bjeavons-zxcvbn-php
- raise dependency on PHP 7.2
- switch to phpunit8

* Fri Mar  1 2019 Remi Collet <remi@remirepo.net> - 4.4.2-1
- initial package, version 4.4.2
